@@ -17,10 +17,24 @@ Used to highlight a particular value.
 
 =head1 SYNOPSIS
 
+ use Chart::Clicker::Decoration::Marker;
+ use Chart::Clicker::Drawing::Color;
+ use Chart::Clicker::Drawing::Stroke;
+
+ my $mark = Chart::Clicker::Decoration::Marker({
+    color => new Chart::Clicker::Drawing::Color({ name => 'red' }),
+    stroke => new CHart::Clicker::Drawing::Stroke(),
+    value => 123
+ });
+
 =head1 METHODS
 
 =head2 Constructor
 
+=over 4
+
+=item new
+
 =cut
 sub new {
     my $proto = shift();
@@ -45,24 +59,26 @@ sub new {
     return $self;
 }
 
+=back
+
 =head2 Class Methods
 
 =over 4
 
-=item $above = $m->above($above)
+=item above
 
 Set/Get the 'above' flag that determines if a marker is drawn above or below
 the rendered values.
 
-=item $color = $m->color($color)
+=item color
 
 Set/Get the color for this marker.
 
-=item $stroke = $m->stroke($stroke)
+=item stroke
 
 Set/Get the stroke for this Marker.
 
-=item $value = $m->value($value)
+=item value
 
 Set/Get the value for this marker.
 
@@ -70,7 +86,7 @@ Set/Get the value for this marker.
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@onemogin.com>
+Cory 'G' Watson <gphat@cpan.org>
 
 =head1 SEE ALSO
 
