@@ -3,12 +3,12 @@ use strict;
 
 use base 'Exporter';
 
-@Chart::Clicker::Drawing::EXPORT_OK = qw();
 @Chart::Clicker::Drawing::EXPORT_OK = qw(
     $CC_HORIZONTAL $CC_VERTICAL $CC_TOP $CC_BOTTOM $CC_LEFT $CC_RIGHT $CC_CENTER
+    $CC_AXIS_TOP $CC_AXIS_BOTTOM $CC_AXIS_LEFT $CC_AXIS_RIGHT
 );
 %Chart::Clicker::Drawing::EXPORT_TAGS = (
-    common => \@Chart::Clicker::Drawing::EXPORT_OK
+    positions => \@Chart::Clicker::Drawing::EXPORT_OK
 );
 
 our $CC_HORIZONTAL = 0;
@@ -18,6 +18,10 @@ our $CC_BOTTOM = 3;
 our $CC_LEFT = 4;
 our $CC_RIGHT = 5;
 our $CC_CENTER = 6;
+our $CC_AXIS_TOP = 7;
+our $CC_AXIS_BOTTOM = 8;
+our $CC_AXIS_LEFT = 9;
+our $CC_AXIS_RIGHT = 10;
 
 =head1 NAME
 
@@ -29,12 +33,12 @@ Chart::Clicker::Drawing holds some common items used in Drawing.
 
 =head1 EXPORTS
 
-$CC_HORIZONTAL;
-$CC_VERTICAL;
-$CC_TOP;
-$CC_BOTTOM;
-$CC_LEFT;
-$CC_RIGHT;
+$CC_HORIZONTAL
+$CC_VERTICAL
+$CC_TOP
+$CC_BOTTOM
+$CC_LEFT
+$CC_RIGHT
 
 =head1 METHODS
 
@@ -50,7 +54,7 @@ $CC_RIGHT;
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@onemogin.com>
+Cory 'G' Watson <gphat@cpan.org>
 
 =head1 SEE ALSO
 
