@@ -26,7 +26,7 @@ my $log = Chart::Clicker::Log->get_logger('Chart::Clicker::Renderer::Bar');
 
 =over 4
 
-=item $image = $r->render($color_allocator)
+=item render
 
 Render the series.
 
@@ -76,7 +76,7 @@ sub render {
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@onemogin.com>
+Cory 'G' Watson <gphat@cpan.org>
 
 =head1 SEE ALSO
 
