@@ -1,7 +1,7 @@
 package Chart::Clicker::Renderer::Base;
 use strict;
 
-use base 'Class::Accessor';
+use base 'Chart::Clicker::Drawing::Component';
 __PACKAGE__->mk_accessors(
     qw(options)
 );
@@ -18,20 +18,13 @@ Chart::Clicker::Renderer::Base represents the plot of the chart.
 
 =cut
 
-use Chart::Clicker::Log;
-
-my $log = Chart::Clicker::Log->get_logger('Chart::Clicker::Renderer::Base');
-
-our $RANGE = 0;
-our $DOMAIN = 1;
-
 =head1 METHODS
 
 =head2 Constructor
 
 =over 4
 
-=item Chart::Clicker::Renderer::Base->new();
+=item new
 
 Creates a new Chart::Clicker::Renderer::Base.
 
@@ -41,9 +34,9 @@ Creates a new Chart::Clicker::Renderer::Base.
 
 =over 4
 
-=item $foo = get_option('foo)
+=item get_option
 
-Returns a value (if it exists) from the options hashref.
+Returns a value for the specified key (if it exists) from the options hashref.
 
 =cut
 sub get_option {
@@ -55,8 +48,21 @@ sub get_option {
     }
 }
 
+=item prepare
 
-=item $image = $r->render($series)
+Prepare the component.
+
+=cut
+sub prepare {
+    my $self = shift();
+    my $clicker = shift();
+    my $dimension = shift();
+
+    $self->width($dimension->width());
+    $self->height($dimension->height());
+}
+
+=item render
 
 Render the series.
 
@@ -69,7 +75,7 @@ sub render {
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@onemogin.com>
+Cory 'G' Watson <gphat@cpan.org>
 
 =head1 SEE ALSO
 
